

set -ex



pcre2grep --version
pcre2-config --version
test -f ${PREFIX}/include/pcre2.h
test -f ${PREFIX}/include/pcre2posix.h
test -f ${PREFIX}/lib/libpcre2-posix${SHLIB_EXT}
test -f ${PREFIX}/lib/libpcre2-posix${SHLIB_EXT}.2
test -f ${PREFIX}/lib/libpcre2-posix${SHLIB_EXT}.2.0.3
test -f ${PREFIX}/lib/libpcre2-8${SHLIB_EXT}
test -f ${PREFIX}/lib/libpcre2-8${SHLIB_EXT}.0
test -f ${PREFIX}/lib/libpcre2-8${SHLIB_EXT}.0.10.0
test -f ${PREFIX}/lib/pkgconfig/libpcre2-8.pc
test -f ${PREFIX}/lib/pkgconfig/libpcre2-posix.pc
exit 0
